@@ -988,7 +988,7 @@ class pkgInfoParsDefaultsSet(icm.Cmnd):
             bisosUserName=bisosUserName,
             bisosGroupName=bisosGroupName,
             rootDir_foreignBxo=rootDir_foreignBxo,
-            rootDir_bisos=rootDir_provisioners,
+            rootDir_provisioners=rootDir_provisioners,
             rootDir_bisos=rootDir_bisos,
             rootDir_bxo=rootDir_bxo,
             rootDir_deRun=rootDir_deRun,
